package com.pnkx.designpatterns.abstractfactory;

import com.pnkx.designpatterns.abstractfactory.factory.LinuxFactory;
import com.pnkx.designpatterns.abstractfactory.factory.SoftwareFactory;
import com.pnkx.designpatterns.abstractfactory.factory.WindowsFactory;
import com.pnkx.designpatterns.abstractfactory.model.Application;
import com.pnkx.designpatterns.abstractfactory.model.OperatingSystem;
import com.pnkx.designpatterns.factorymethod.factory.AnimalFactory;
import com.pnkx.designpatterns.factorymethod.factory.CatFactory;
import com.pnkx.designpatterns.factorymethod.factory.DogFactory;
import com.pnkx.designpatterns.factorymethod.model.Animal;

/**
 * Main
 *
 * @author 裴浩宇
 * @version 1.0
 * @date 2023/10/17 17:52
 * @description 抽象工厂模式客户端
 */
public class Main {
    public static void main(String[] args) {
        // 初始化Windows工厂
        SoftwareFactory windowsFactory = new WindowsFactory();
        // 初始化操作系统
        OperatingSystem windowsOS = windowsFactory.createOperatingSystem();
        // 启动
        windowsOS.run();
        // 初始化应用程序
        Application wechat = windowsFactory.openApplication();
        // 打开
        wechat.open();
        // 初始化Linux操作系统
        SoftwareFactory linuxFactory = new LinuxFactory();
        // 初始化操作系统
        OperatingSystem linuxOS = linuxFactory.createOperatingSystem();
        // 启动
        linuxOS.run();
        // 初始化应用程序
        Application vim = linuxFactory.openApplication();
        // 打开
        vim.open();
    }
}
